#!/bin/bash
#-- ----------------------------------------------------------------------
#-- jloader.ksh
#--
#-- This script acts as an entry point to the JLoader. This is a standalone
#-- loader which can be configured to process archive files (tar/gzip/zip)
#-- at multiple levels.
#-- These are termed the Readers
#-- It also supports the use of per file type processors which process
#-- the file input
#--
#-- ----------------------------------------------------------------------
while [ $# -gt 0 ]
do
case $1 in

    -filename)
            shift

            FULLNAME=$1
	    MTX_DIRNAME=`echo $FULLNAME | awk 'BEGIN {FS="/"}{print $4}'`
	    echo "MTX_DIRNAME is $MTX_DIRNAME \n"
            FILENAME=`basename $1`

            if ! test -s $1
            then
              echo "ERROR: $FILENAME not valid file size"
              echo "Reason: $FILENAME must be greater than 0 size."
              exit 1
            fi

            DIRNAME=`dirname $1`
            FILEMAIN=${FILENAME%.*}
            FILEEXT=${FILENAME##*.}
            echo "FILENAME->"$FILENAME
            echo "FILEMAIN->"$FILEMAIN
            echo "FILEEXT->"$FILEEXT

            TOKENS=`echo $FILENAME | tr '.' ' '`
            NUM_TOKENS=`echo $TOKENS | wc -w`
	    RNCNAME=`echo $FILENAME | awk '{FS="."}{print $1}'`
	    TSTAMP=`echo $FILENAME | awk '{FS="."}{print $2}'`
	   SYSID=`grep "$RNCNAME " $PROSPECT_HOME/msc_list|awk ' {print $2}'`
            RNCID=`grep "$RNCNAME " $PROSPECT_HOME/msc_list|awk ' {print $3}'`

#            ARGS="$ARGS -filename $FULLNAME"
            ;;
    *) 
    echo "SYSID=$SYSID and RNCID=$RNCID \n";
        ARGS="$ARGS $1"
        ;;

esac
shift
done
echo $ARGS

FILESIZE=`ls -alrt $FULLNAME| awk 'BEGIN {FS=" "}{print $5}'`

echo "FILESIZE is $FILESIZE \n";
if [[ $FILESIZE -lt 201  ]];
then
   WORD_CNT=`cat $FULLNAME | grep -v "^#" | wc -l`
   if [[ $WORD_CNT -eq 0 ]]
   then
      echo "The file has no contents hence it will move to fail directory! "
      exit 1;
   fi
fi

echo "RNCNAME is $RNCNAME and TSTAMP = $TSTAMP \n";
echo "SYSID=$SYSID and RNCID=$RNCID \n";
if [ -z	"$JAVA_HOME" ];	then
  echo "ERROR: JAVA_HOME not found in your environment."
  echo ""
  echo "Please,	set the	JAVA_HOME environment variable to match	the"
  echo "root directory of the Java Virtual Machine you want to use."
  echo ""
  exit 1;
else
  echo PATH | grep $JAVA_HOME || PATH=$JAVA_HOME/bin:$PATH
fi

if [ -z "$JAVA_HOME/lib/tools.jar" ]; then
  echo "ERROR: Either your JDK is too old, or I was unable to find"
  echo "lib/tools.jar in your JAVA_HOME directory.  Please make"
  echo "sure you have a Java2-compliant compiler and JVM."
  exit 2;
else
  CLASSPATH="$JAVA_HOME/lib/tools.jar"
fi

JAVA_SHARED="/usr/share/java"

#FLEXPM_HOME=`pwd`
#JLOADER_HOME=./jloader
JLOADER_HOME=$FLEXPM_HOME/pm/jloader
JLOADER_LIB=$JLOADER_HOME/lib
LOG_DIR=$PROSPECT_HOME/../ftpIN/${MTX_DIRNAME}/logs

if [[ "$DB_HOSTIP" != "" ]];
then
  HOST=$DB_HOSTIP
else
  HOST=`hostname`
fi

if [[ "$JLOADER_LISTENER_PORT" != "" ]];
then
  LISTENER_PORT=$JLOADER_LISTENER_PORT
else
  LISTENER_PORT=1521
fi
echo "HOST IS $HOST  \n"
echo "LISTENER PORT IS $LISTENER_PORT\n"
# set the class path
#UNIXCP="$JLOADER_LIB/ojdbc14.jar:$JLOADER_LIB/wm-jam-common.jar"
#UNIXCP="$UNIXCP:$JLOADER_LIB/log4j-1.2.8.jar:$JLOADER_LIB/jloader.jar:$JLOADER_LIB/commons-cli-1.0.jar"
#UNIXCP="$UNIXCP:$JLOADER_LIB/jdom.jar"
#UNIXCP="$UNIXCP:$JLOADER_LIB/tar.jar:$JLOADER_LIB/xercesImpl.jar"
#UNIXCP="$UNIXCP:$JLOADER_LIB/xml-apis.jar"

UNIXCP=""

for jarfile in `find $JLOADER_LIB -name '*.jar' -print 2>/dev/null`
do
  UNIXCP="$UNIXCP:$jarfile"
  done

# Now tack on the plugins to the classpath. All the Application Engineers have to do is supply
# the appropriate jar file and drop it into the plugins directory.
for jarfile in `find $JLOADER_LIB/plugins -name '*.jar' -print 2>/dev/null`
do
  UNIXCP="$UNIXCP:$jarfile"
done


# set the arguments

CLI_ARGS="$@"

# database properties
DB_PROPERTIES="-Ddb.name=$DBSID -Ddb.user=$DBUSER -Ddb.pass=$DBPASSWD -Ddb.host=$HOST -Ddb.listener.port=$LISTENER_PORT"

#get current date and time for main log file
TIME_STAMP=`date '+20%y-%m-%dT%H:%M:%S'`

# other properties required by jloader
NONDB_PROPERTIES="-Dlog.dir=$LOG_DIR -Dtime.stamp=$TIME_STAMP -DFLEXPM_HOME=$FLEXPM_HOME"

echo " 	  jloader> classpath $UNIXCP"
echo "    jloader> passing arguments $CLI_ARGS"
ARGS="$CLI_ARGS"

#UNIXCP=`cygpath --path --windows $UNIXCP`

# the main class
MAINCLASS="com.watchmark.jloader.main.JLoader"

heap="-Xmx512M"

PATH="$JAVA_HOME/bin:$PATH"

echo "Using filename as $FULLNAME \n"
CLI_ARGS="-log4j $PROSPECT_HOME/1xEVDO/scripts/jloader/log4j.xml -config $PROSPECT_HOME/1xEVDO/scripts/jloader/config.xml -file $FULLNAME"
#CLI_ARGS="-log4j log4j.xml -config config.xml -file $FULLNAME

echo ${PMDEPENDPROGRAM} -service ${PM_PORT}@${WM_SERVER} \
                        -d ${SYSID}-${RNCID} -file ${FILENAME}
${PMDEPENDPROGRAM} -service ${PM_PORT}@${WM_SERVER} \
                        -d ${SYSID}-${RNCID} -file ${FILENAME} &


$JAVA_HOME/bin/java $heap -cp $UNIXCP $DB_PROPERTIES $NONDB_PROPERTIES $MAINCLASS $CLI_ARGS
retCode=$?

if [[ ${retCode} -eq 0 ]];
then
  echo "Calling data availability procedure \n";
  sqlplus ${DB_CONNECT} <<EOF1
  set echo on;
  set timing on
   exec wm_availabledata_pkg.file_load($SYSID , $RNCID,  '$TSTAMP', 'DORNC' , 'loadOK');
EOF1
fi

#The foll.code will zip the RNCpm file. We will return 0 no matter what because 
# if gzip is not successful, loader will put the processed file into fail dir.
OK_DIR=$PROSPECT_HOME/../ftpIN/${MTX_DIRNAME}/ok
FAIL_DIR=$PROSPECT_HOME/../ftpIN/${MTX_DIRNAME}/fail
IN_DIR=$PROSPECT_HOME/../ftpIN/${MTX_DIRNAME}/in

#set -x
if [[ ${retCode} -eq 0 ]];
then
  mv $IN_DIR/$FILENAME $OK_DIR/$FILENAME
gzip -9 -f $OK_DIR/$FILENAME
echo "*******************************************************************************************************"
echo "The $FILENAME has been moved to the ok directory and gzipped. File has been processed successfully." 
echo "*******************************************************************************************************"
exit 0
else
  mv $IN_DIR/$FILENAME $FAIL_DIR/$FILENAME
gzip -9 -f $FAIL_DIR/$FILENAME
echo "*******************************************************************************************************"
echo "The $FILENAME has been moved to the fail directory and gzipped. File processed failed for some reason."
echo "*******************************************************************************************************"
exit 0
fi

